searchData={"content_type":"text/markdown","items":[{"doc":"LiveViewNative keeps the contexts that define your domain\nand business logic.\n\nContexts are also responsible for managing your data, regardless\nif it comes from the database, an external API or others.","ref":"LiveViewNative.html","title":"LiveViewNative","type":"module"},{"doc":"","ref":"LiveViewNative.html#platform/1","title":"LiveViewNative.platform/1","type":"function"},{"doc":"","ref":"LiveViewNative.html#platform!/1","title":"LiveViewNative.platform!/1","type":"function"},{"doc":"","ref":"LiveViewNative.html#platforms/0","title":"LiveViewNative.platforms/0","type":"function"},{"doc":"Upgrades a Live Component to a Native Live Component when inherited\nwith `use LiveViewNative.Component` like so:\n\n```\ndefmodule MyApp.MyComponent do\n  use MyAppWeb, :live_component\n  use LiveViewNative.Component\n\n  # ...\nend\n```","ref":"LiveViewNative.Component.html","title":"LiveViewNative.Component","type":"module"},{"doc":"A GenServer that provides additional services in development environments.\nIt supports multicast addressing over UDP to provide visibility between\nLiveView Native development servers and clients running on the same network.","ref":"LiveViewNative.DevServer.html","title":"LiveViewNative.DevServer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LiveViewNative.DevServer.html#child_spec/1","title":"LiveViewNative.DevServer.child_spec/1","type":"function"},{"doc":"","ref":"LiveViewNative.DevServer.html#endpoint_config/1","title":"LiveViewNative.DevServer.endpoint_config/1","type":"function"},{"doc":"","ref":"LiveViewNative.DevServer.html#init/1","title":"LiveViewNative.DevServer.init/1","type":"function"},{"doc":"","ref":"LiveViewNative.DevServer.html#start_link/1","title":"LiveViewNative.DevServer.start_link/1","type":"function"},{"doc":"This macro is largely responsible for upgrading a LiveView or Live Component\nto a module that supports LiveView Native. This macro should not be directly\ninherited by a LiveView or Live Component via `use`; instead, those modules\nshould use `LiveViewNative.LiveView` or `LiveViewNative.LiveComponent`\nrespectively.","ref":"LiveViewNative.Extensions.html","title":"LiveViewNative.Extensions","type":"module"},{"doc":"LiveView Native extension that enables inline-rendering of templates for LiveView\nNative platforms within a LiveView or Live Component. Using this macro causes\na module to inherit a `LVN/2` sigil that can be used to render templates inline\nby suffixing it with the platform's `platform_id`:\n\n```elixir\ndefmodule MyAppWeb.HelloLive do\n  use Phoenix.LiveView\n  use LiveViewNative.LiveView\n\n  @impl true\n  def render(%{platform_id: :swiftui} = assigns) do\n    ~LVN\"\"\"\n      foreground_style(primary: {:color, :mint})}>\n      Hello from iOS!\n     \n    \"\"\"swiftui\n  end\n\n  def render(assigns) do\n    ~H\"\"\"\n     Hello from the web! \n    \"\"\"\n  end\nend\n```","ref":"LiveViewNative.Extensions.InlineRender.html","title":"LiveViewNative.Extensions.InlineRender","type":"module"},{"doc":"LiveView Native extension for platform-specific modifiers. Modifiers refer to\nproperties that affect the behavior and visual presentation of native components,\nsuch as alignment, visibility, styling, and so on. Each platform library defines\nits own set of supported modifiers as well as how to encode those modifiers before\nthey are returned from the LiveView server to the client.\n\nA modifier is a struct that implements the `LiveViewNativePlatform.Modifier` protocol\nand optionally defines any number of functions with the name `params` of any arity up\nto 6. The `params` function is used to encode the modifier before it is added to the\nmodifier stack when applying the modifier as part of a LiveView Native HEEx template.\nFor example:\n\n```elixir\ndefmodule MyPlatform.Modifiers.Bold do\n  use LiveViewNativePlatform.Modifier\n\n  modifier_schema \"bold\" do\n    field :is_active, :boolean, default: true\n  end\n\n  def params(is_active) when is_boolean(is_active), do: [is_active: is_active]\n  def params(params), do: params\nend\n```\n\nThis module defines a modifier named `bold` that can be constructed by passing a boolean\nor any value that can be cast to a modifier schema (an option list, map or struct of the\nsame module). It could be called any of the following ways from a LiveView Native HEEx\ntemplate:\n\n```heex\n This text is bold \n```\n\nThis example demonstrates using `bold/1` as the first modifier in a chain. It is called\nwith a boolean which is then passed to `params/1`. `true` matches the `is_boolean/1` guard\nand so an option list is returned with the value of `:is_active` being `true`. Finally,\nthat option list is cast to `%MyPlatform.Modifiers.Bold{}` which gets wrapped in a new\nmodifier builder as the return value.\n\n```heex\n This text is bold too. \n```\n\nThis `bold/1` call also occurs at the beginning of a chain but here it is called with\nan option list. The option list falls back to the second function clause of `params/1`\nand is returned as is, being cast to `%MyPlatform.Modifiers.Bold{}` and wrapped in a\nmodifier builder which is returned.\n\n```heex\n  bold(true)}>Oh, and this one as well. \n```\n\nHere, the modifier is being called in the middle of a chain as `bold/2` with the first\nvalue being a modifier builder returned by `some_other_modifier/0` and the second value\nbeing a boolean. All of the same steps as the first example are applied with the return\nvalue being `%MyPlatform.Modifiers.Bold{is_active: true}`. This modifier is added to the\nmodifier builder stack through its implementation of `LiveViewNativePlatform.ModifiersStack`.\nThe modifier builder is then returned with the modifier added to the stack.\n\n```heex\n  bold(%{is_active: true})}>And even this one as well. \n```\n\nThis example is the same as the previous one except that the second value is an option\nlist. The same steps are applied as the second example, with the same return value being\nadded to the passed modifier builder's stack.\n\nThe \"modifier builder\" that gets returned in all of these examples is a custom struct\ndefined by the platform library that provides the modifier function being called. In all\ncases, it is a module that implements the following protocols:\n\n  * `LiveViewNativePlatform.ModifiersStack`\n  * `Jason.Encoder`\n  * `Phoenix.HTML.Safe`\n\nThese implementations are used for appending modifiers, encoding them as JSON and rendering\nthem as HTML attributes respectively. For platforms that don't provide a modifier builder\nstruct, a `%LiveViewNativePlatform.GenericModifiers{}` is used as a fallback.","ref":"LiveViewNative.Extensions.Modifiers.html","title":"LiveViewNative.Extensions.Modifiers","type":"module"},{"doc":"LiveView Native extension for swapping the `render/1` function when rendering\nfor specific platforms from a LiveView or Live Component. Using this macro causes\na module to inherit a `render_native/1` function which takes a map of assigns and\ncalls `render/1` on the render module for the calling platform as defined by the\n`LiveViewNativePlatform.Env` struct set to the `:native` assign. The module\nwhere that platform-specific `render/1` function lives is derived by concatenating\nthe LiveView or LiveComponent's module name with the platform context struct's\n`template_namespace` and should be automatically generated from a LiveView or Live\nComponent that uses `LiveViewNative.LiveView` or `LiveViewNative.LiveComponent`\nrespectively.\n\nThis extension effectively allows a native-enabled LiveView or Live Component to\nsupport a distinct render context for each platform, allowing for platform-specific\ntemplates, modifiers, etc.","ref":"LiveViewNative.Extensions.Render.html","title":"LiveViewNative.Extensions.Render","type":"module"},{"doc":"TODO: Write docs","ref":"LiveViewNative.Extensions.RenderMacro.html","title":"LiveViewNative.Extensions.RenderMacro","type":"module"},{"doc":"LiveView Native extension for rendering platform-specific templates.\nTakes the following parameters which are typically derived from a `Macro.Env`\nstruct:\n\n- `tag_handler` (optional) - a module implementation of `Phoenix.LiveView.TagEngine`\n- `template_basename` - base filename of the template\n- `template_directory` - root path of the template\n- `template_extension` - file extension of the template\n\nIf a template file and engine exist for the given parameters, a `render/1` function\nis generated which renders the template using that template engine.","ref":"LiveViewNative.Extensions.Templates.html","title":"LiveViewNative.Extensions.Templates","type":"module"},{"doc":"Upgrades a Live Component to a Native Live Component when inherited\nwith `use LiveViewNative.LiveComponent` like so:\n\n```\ndefmodule MyApp.MyComponent do\n  use MyAppWeb, :live_component\n  use LiveViewNative.LiveComponent\n\n  # ...\nend\n```","ref":"LiveViewNative.LiveComponent.html","title":"LiveViewNative.LiveComponent","type":"module"},{"doc":"Ensures common `assigns` are applied to all LiveViews attaching this hook.","ref":"LiveViewNative.LiveSession.html","title":"LiveViewNative.LiveSession","type":"module"},{"doc":"","ref":"LiveViewNative.LiveSession.html#on_mount/4","title":"LiveViewNative.LiveSession.on_mount/4","type":"function"},{"doc":"Upgrades a LiveView to a Native LiveView when inherited with\n`use LiveViewNative.LiveView` like so:\n\n```\ndefmodule MyApp.MyLive do\n  use MyAppWeb, :live_view\n  use LiveViewNative.LiveView\n\n  # ...\nend\n```","ref":"LiveViewNative.LiveView.html","title":"LiveViewNative.LiveView","type":"module"},{"doc":"","ref":"LiveViewNative.Modclasses.html","title":"LiveViewNative.Modclasses","type":"module"},{"doc":"Provides configuration constants about all platforms supported by an\napplication that uses LiveView Native. This module is a dependency\nof various LiveView Native systems, such as `LiveViewNative.LiveSession`\nwhich is responsible for determining which platform (web, iOS, etc.) a\nsession originates from.","ref":"LiveViewNative.Platforms.html","title":"LiveViewNative.Platforms","type":"module"},{"doc":"","ref":"LiveViewNative.Platforms.html#env_platform/1","title":"LiveViewNative.Platforms.env_platform/1","type":"function"},{"doc":"","ref":"LiveViewNative.Platforms.html#env_platforms/0","title":"LiveViewNative.Platforms.env_platforms/0","type":"function"},{"doc":"","ref":"LiveViewNative.Platforms.Web.html","title":"LiveViewNative.Platforms.Web","type":"module"},{"doc":"","ref":"LiveViewNative.TagEngine.html","title":"LiveViewNative.TagEngine","type":"module"},{"doc":"","ref":"LiveViewNative.TagEngine.html#classify_type/1","title":"LiveViewNative.TagEngine.classify_type/1","type":"function"},{"doc":"","ref":"LiveViewNative.TagEngine.html#void?/1","title":"LiveViewNative.TagEngine.void?/1","type":"function"},{"doc":"","ref":"LiveViewNative.Templates.html","title":"LiveViewNative.Templates","type":"module"},{"doc":"","ref":"LiveViewNative.Templates.html#precompile/1","title":"LiveViewNative.Templates.precompile/1","type":"function"},{"doc":"# About\n\n> ##","ref":"about.html","title":"About","type":"extras"},{"doc":"> LiveView Native is _prerelease software_ and not recommended for production use.\n\nLiveView Native is a platform for building native applications using [Elixir](https://elixir-lang.org/) and [Phoenix LiveView](https://github.com/phoenixframework/phoenix_live_view). It allows a single LiveView to serve a variety of clients by transforming platform-specific template code into native user interfaces. Here is a basic example:\n\n```elixir\n# hello_live.ex\ndefmodule MyApp.HelloLive do\n  use Phoenix.LiveView\n  use LiveViewNative.LiveView\n\n  @impl true\n  def render(assigns) do\n    # render_native/1 is provided by LiveViewNative.LiveView.\n    # It takes care of rendering the correct .heex template\n    # for each platform \n    render_native(assigns)\n  end\nend\n```\n\nThis allows us to define a specific template for each platform:\n\n \n\n#","ref":"about.html#warning-warning","title":"Warning {: .warning} - About","type":"extras"},{"doc":"```heex\n \n \n   \n     Hello from the web! \n   \n \n```\n\n#","ref":"about.html#web","title":"Web - About","type":"extras"},{"doc":"```heex\n \n \n   \n     Hello from SwiftUI! \n   \n \n```\n\n \n\nThis library provides a base SDK that allows Elixir developers to use LiveView Native within their own Phoenix projects. If you're a platform developer interested in adding native support for LiveView Native to your own client code, check out [live_view_native_platform](https://github.com/liveview-native/live_view_native_platform).","ref":"about.html#swiftui","title":"SwiftUI - About","type":"extras"},{"doc":"# Installation\nTo use LiveView Native, add it to your list of dependencies in `mix.exs`.\n\n```elixir\ndef deps do\n  [{:live_view_native, \"~> 0.0.7\"}]\nend\n```","ref":"installation.html","title":"Installation","type":"extras"},{"doc":"The `live_view_native` Hex package isn't useful on its own. You also need to add any platform libraries you want your application to support.\n\nYou can add any number of platform libraries, allowing you to serve a variety of non-web clients from the same application.\n\n \n\n#","ref":"installation.html#adding-platform-libraries","title":"Adding platform libraries - Installation","type":"extras"},{"doc":"Supported platforms:\n* iOS 16+\n* macOS 13+\n* watchOS 9+\n\n> ##","ref":"installation.html#swiftui","title":"SwiftUI - Installation","type":"extras"},{"doc":"> For more information, see the platform-specific documentation: [`live_view_native_swift_ui`](https://github.com/liveview-native/liveview-client-swiftui)\n```elixir\ndef deps do\n  [\n    # ...\n    {:live_view_native_swift_ui, \"~> 0.0.9\"}\n  ]\nend\n```\nThe list of supported platforms, along with their configuration, is defined within your application's Mix configuration:\n```elixir\n# config.exs\nimport Config\n\n# ...\n\n# Define platform support for LiveView Native\nconfig :live_view_native,\n  platforms: [\n    LiveViewNativeSwiftUi.Platform\n  ]\n\nconfig :live_view_native, LiveViewNativeSwiftUi.Platform, app_name: \"My App\"\n```\n\n#","ref":"installation.html#platform-documentation-info","title":"Platform Documentation {: .info} - Installation","type":"extras"},{"doc":"Supported platforms:\n* Android\n\n> ##","ref":"installation.html#jetpack-compose","title":"Jetpack Compose - Installation","type":"extras"},{"doc":"> For more information, see the platform-specific documentation: [`live_view_native_jetpack`](https://github.com/liveview-native/liveview-client-jetpack)\n```elixir\ndef deps do\n  [\n    # ...\n    {:live_view_native_jetpack, \"~> 0.0.9\"}\n  ]\nend\n```\nThe list of supported platforms, along with their configuration, is defined within your application's Mix configuration:\n```elixir\n# config.exs\nimport Config\n\n# ...\n\n# Define platform support for LiveView Native\nconfig :live_view_native,\n  platforms: [\n    LiveViewNativeJetpack.Platform\n  ]\n\nconfig :live_view_native, LiveViewNativeJetpack.Platform, app_name: \"My App\"\n```\n\n \n\nFinally, each platform has its own implementation details for connecting a native client application to a LiveView Native backend. For example, if you want to support `live_view_native_swift_ui` you'll need to [create an App in Xcode](https://liveview-native.github.io/liveview-client-swiftui/tutorials/liveviewnative/01-initial-list#Creating-the-App) and use the `LiveViewNative` Swift dependency to render a clientside [LiveView](https://liveview-native.github.io/liveview-client-swiftui/documentation/liveviewnative/liveview) that connects to your Phoenix server:\n\n```swift\n// MyApp.swift\nimport SwiftUI\n\n@main\nstruct MyApp: App {\n    var body: some Scene {\n        WindowGroup {\n            ContentView()\n        }\n    }\n}\n\n//  ContentView.swift\nimport SwiftUI\nimport LiveViewNative\n\nstruct ContentView: View {\n    var body: some View {\n        LiveView(.localhost)\n    }\n}\n```\n\nFor more information on how to configure a LiveView Native project for a specific platform, please visit the documentation page for that platform library.","ref":"installation.html#platform-documentation-info","title":"Platform Documentation {: .info} - Installation","type":"extras"},{"doc":"# Change Events\n\nIn LiveView Native, elements can support client-side changes to their value outside of a ` `.\nSynchronizing the values must be handled manually by the LiveView using change events.","ref":"change-events.html","title":"Change Events","type":"extras"},{"doc":"Use the `phx-change` attribute to respond to client-side changes to an element's value.\n\n```html\n \n```\n\nA [`handle_event/3`](`c:Phoenix.LiveView.handle_event/3`) implementation with the name `\"value-changed\"` will be called anytime the user changes the text of the `TextField`.\n\n```elixir\ndef handle_event(\"value-changed\", new_value, socket) do\n  {:noreply, assign(socket, text: new_value)}\nend\n```\n\nThe `phx-debounce`, `phx-throttle`, and `phx-target` attributes can be used to configure the event.\n\nRefer to the documentation for an element to find out if it supports client-side changes.","ref":"change-events.html#client-side-changes","title":"Client-side changes - Change Events","type":"extras"},{"doc":"Each element has an attribute that controls its value.\nFor example, `TextField` in the SwiftUI client uses the attribute `text`.\nSee the documentation for an element to find out what attribute it uses.\n\nWhenever the attribute's value is changed, the client will update to display the new value.\nNo change event is sent when the server updates the value.","ref":"change-events.html#server-side-changes","title":"Server-side changes - Change Events","type":"extras"},{"doc":"Some modifiers have values that can be changed by the client.\n\nTo receive change events on these modifiers, pass a `LiveViewNativePlatform.Modifier.Types.Event` to the `change` argument.\n\n```elixir\nsheet(is_presented: @show, change: \"presentation-changed\")\n```\n\nProvide a map to `change` for more advanced configuration.\n\n```elixir\nsheet(is_presented: @show, change: %{ event: \"presentation-changed\", debounce: 2000, target: @myself })\n```\n\nA change event will be sent with every argument of the modifier that can be change-tracked.\n\n```elixir\ndef handle_event(\"presentation-changed\", %{ \"is_presented\" => show }, socket) do\n  {:noreply, assign(socket, show: show)}\nend\n```\n\nIn the example above, the server can show/hide the sheet by setting the `show` assign.\nWhen the user swipes down on the sheet to close it, the `\"presentation-changed\"` event will be called with the value `false`.\n\nSee the documentation for a modifier to find out which arguments can be change-tracked.","ref":"change-events.html#modifier-change-events","title":"Modifier change events - Change Events","type":"extras"}]}